###########################
# Processing BC Data
###########################
# Clearing Workspace and loading packages
# rm(list = ls())
# setwd() # Set this to preferred working directory 

# Reading Data
Marty_Data <- read.csv("Marty_Data.csv", header = F, na.strings = "")
Marty_Data <- Marty_Data[2:2507, 1:23] # Removes the Excel cells with calculations
names(Marty_Data) <- c("Number", "Number_on_Map", "Date", "Month","Year", "age",
                    "year_class", "entry_date", "number_of_fish", 
                    "chalimus_per_fish", "motiles_per_fish", "females_per_fish", 
                    "three_month_series", "estimate_type", "caligulus_per_fish",
                    "treatment", "temperature", "salinity", "comments",
                    "total_motiles", "total_females", "total_caligulus",
                    "caligus_calculation")
head(Marty_Data)

# Formatting Date Data
Marty_Data$Date <- (gsub(x = Marty_Data$Date, pattern = "Jan-", 
                         replacement = "01/01/", perl = TRUE))
Marty_Data$Date <- (gsub(x = Marty_Data$Date, pattern = "Feb-", 
                         replacement = "02/01/", perl = TRUE))
Marty_Data$Date <- (gsub(x = Marty_Data$Date, pattern = "Mar-",
                         replacement = "03/01/", perl = TRUE))
Marty_Data$Date <- (gsub(x = Marty_Data$Date,pattern = "Apr-", 
                         replacement = "04/01/", perl = TRUE))
Marty_Data$Date <- (gsub(x = Marty_Data$Date, pattern = "May-",
                         replacement = "05/01/", perl = TRUE))
Marty_Data$Date <- (gsub(x = Marty_Data$Date, pattern = "Jun-",
                         replacement = "06/01/", perl = TRUE))
Marty_Data$Date <- (gsub(x = Marty_Data$Date, pattern = "Jul-",
                         replacement = "07/01/", perl = TRUE))
Marty_Data$Date <- (gsub(x = Marty_Data$Date, pattern = "Aug-", 
                         replacement = "08/01/", perl = TRUE))
Marty_Data$Date <- (gsub(x = Marty_Data$Date, pattern = "Sep-", 
                         replacement = "09/01/", perl = TRUE))
Marty_Data$Date <- (gsub(x = Marty_Data$Date, pattern = "Oct-",
                         replacement = "10/01/", perl = TRUE))
Marty_Data$Date <- (gsub(x = Marty_Data$Date, pattern = "Nov-", 
                         replacement = "11/01/", perl = TRUE))
Marty_Data$Date <- (gsub(x = Marty_Data$Date, pattern = "Dec-", 
                         replacement = "12/01/", perl = TRUE))

Marty_Data$Date <- as.Date(Marty_Data$Date, format = "%m/%d/%y")
Marty_Data$Date <- as.POSIXct(Marty_Data$Date, "%D")

# Formatting other columns to correct data type
Marty_Data$temperature <- as.numeric(as.character(Marty_Data$temperature)) 
Marty_Data$salinity <- as.numeric(as.character(Marty_Data$salinity)) 

Marty_Data$chalimus_per_fish <- as.numeric(as.character(Marty_Data$chalimus_per_fish)) 
Marty_Data$females_per_fish <- as.numeric(as.character(Marty_Data$females_per_fish)) 
Marty_Data$chalimus_per_fish[is.na(Marty_Data$chalimus_per_fish)] <- 0
Marty_Data$females_per_fish[is.na(Marty_Data$females_per_fish)] <- 0

## Farm/Dates chosen because temp/salinity collected most months and treatment was late
farm3 <- Marty_Data[281:300, ]
unclassed.time <- unclass(farm3$Date)
timevalues <- seq(min(unclassed.time), max(unclassed.time), 100000)
f3.temperature <- farm3$temperature
f3.salinity <- farm3$salinity

# Fitting temperature lm()
temp.lm <- lm(farm3$temperature ~ sin(2 * pi * unclassed.time / 31556940)
              + cos(2 * pi * unclassed.time / 31556940)) 
predictedTEMP <- predict(temp.lm, list(unclassed.time = timevalues))
summary(temp.lm)

# Fitting salinity lm()
sal.lm <- lm(farm3$salinity ~ sin(2 * pi * unclassed.time / 31556940)
             + cos(2 * pi * unclassed.time / 31556940))
predictedPSU <- predict(sal.lm, list(unclassed.time = timevalues))

## Data for ggPlot
BC.environment <- as.data.frame(cbind(timevalues, predictedTEMP, predictedPSU,
                                      unclassed.time, f3.temperature, f3.salinity))
write.csv(BC.environment, file = "BCenvironment",
          row.names = FALSE)

# Min/Max/Mean of Temperature and Salinity in BC
quantile(f3.temperature, 0.05, na.rm = TRUE)
median(f3.temperature, na.rm = TRUE)
quantile(f3.temperature, 0.95, na.rm = TRUE)

quantile(f3.salinity, 0.05, na.rm = TRUE)
median(f3.salinity, na.rm = TRUE)
quantile(f3.salinity, 0.95, na.rm = TRUE)

###########################
# Processing NL Data
###########################

## NOVA cleaned of negative data (12/13/2013 onwards)
nova <- read.csv("nova.csv")
nova <- nova[1:40969, ] # Temperatures are large negatives (i.e. -10C) after this
attach(nova)

# Formatting timestamp data into usable formats
TIMESTAMP <- as.POSIXct(TimeStamp, "%m/%d/%Y %H:%M", tz = "America/St_Johns")
unclassed.time <- unclass(TIMESTAMP) # for lm()
timevalues <- seq(min(unclassed.time), max(unclassed.time), 100000)#for predict()

# Corrects machine readings to practical salinity units
ConvertToPSU <- function(C){ # Corrects machine readings to practical salinity units
  (0.008 - 0.1692 * (C / 42.914) ^ (1 / 2) + 25.3851 * (C / 42.914) 
   + 14.0941 * (C / 42.914) ^ (3 / 2) - 7.0261 * (C / 42.914) ^ 2 
   + 2.7081 * (C / 42.914) ^ (5/2))
}

PSU1 <- ConvertToPSU(S1[1:length(S1)])
PSU2 <- ConvertToPSU(S2[1:length(S2)])
PSU3 <- ConvertToPSU(S3[1:length(S3)])

## Fitting Sinusoidal Curve to Temperature Data at Depth #3
temp.lm <- lm(T3 ~ sin(2 * pi * unclassed.time / 31556940) # of seconds in year
              + cos( 2 * pi * unclassed.time / 31556940)) # of seconds in year
predictedTEMP <- predict(temp.lm, list(unclassed.time = timevalues))
summary(temp.lm)

## Fitting Sinusoidal Curve to Salinity Data at Depth #3
sal.lm <- lm(PSU3 ~ sin(2 * pi * unclassed.time / 31556940) # of seconds in year
             + cos(2 * pi * unclassed.time / 31556940)) # of seconds in year
predictedPSU <- predict(sal.lm, list(unclassed.time = timevalues))
summary(sal.lm)

# Saving outputs for ggPlot
NL.environment <- as.data.frame(cbind(timevalues, predictedTEMP, predictedPSU, 
                                      unclassed.time, T3, PSU3))
write.csv(NL.environment, file = "NLenvironment",
          row.names = FALSE)

# Min/Max/Mean of temperature and salinity in NL
quantile(T3, 0.05, na.rm = TRUE)
median(T3, na.rm = TRUE)
quantile(T3, 0.95, na.rm = TRUE)

quantile(PSU3, 0.05, na.rm = TRUE)
median(PSU3, na.rm = TRUE)
quantile(PSU3, 0.95, na.rm = TRUE)



